==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/StackedSplineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalStackedSeriesBaseDescriptionMetadata } from "./HorizontalStackedSeriesBaseDescriptionMetadata";
import { StackedSplineSeriesDescription } from "./StackedSplineSeriesDescription";
/**
 * @hidden
 */
var StackedSplineSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(StackedSplineSeriesDescriptionMetadata, _super);
    function StackedSplineSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    StackedSplineSeriesDescriptionMetadata.b = function (a) {
        if (StackedSplineSeriesDescriptionMetadata.a == null) {
            StackedSplineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            StackedSplineSeriesDescriptionMetadata.c(StackedSplineSeriesDescriptionMetadata.a);
        }
        if (a.g(StackedSplineSeriesDescriptionMetadata.a)) {
            return;
        }
        a.s(StackedSplineSeriesDescriptionMetadata.a);
    };
    StackedSplineSeriesDescriptionMetadata.c = function (a) {
        HorizontalStackedSeriesBaseDescriptionMetadata.c(a);
        a.item("IsSplineShapePartOfRange", "Boolean");
    };
    StackedSplineSeriesDescriptionMetadata.d = function (a) {
        StackedSplineSeriesDescriptionMetadata.b(a);
        a.u("StackedSplineSeries", function () { return new StackedSplineSeriesDescription(); });
        a.t("StackedSplineSeries", StackedSplineSeriesDescriptionMetadata.a);
    };
    StackedSplineSeriesDescriptionMetadata.$t = markType(StackedSplineSeriesDescriptionMetadata, 'StackedSplineSeriesDescriptionMetadata');
    StackedSplineSeriesDescriptionMetadata.a = null;
    return StackedSplineSeriesDescriptionMetadata;
}(Base));
export { StackedSplineSeriesDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/StackedSplineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalStackedSeriesBaseDescriptionMetadata } from "./HorizontalStackedSeriesBaseDescriptionMetadata";
import { StackedSplineSeriesDescription } from "./StackedSplineSeriesDescription";
/**
 * @hidden
 */
var StackedSplineSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(StackedSplineSeriesDescriptionMetadata, _super);
    function StackedSplineSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    StackedSplineSeriesDescriptionMetadata.b = function (a) {
        if (StackedSplineSeriesDescriptionMetadata.a == null) {
            StackedSplineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            StackedSplineSeriesDescriptionMetadata.c(StackedSplineSeriesDescriptionMetadata.a);
        }
        if (a.j(StackedSplineSeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(StackedSplineSeriesDescriptionMetadata.a);
    };
    StackedSplineSeriesDescriptionMetadata.c = function (a) {
        HorizontalStackedSeriesBaseDescriptionMetadata.c(a);
        a.item("IsSplineShapePartOfRange", "Boolean");
    };
    StackedSplineSeriesDescriptionMetadata.d = function (a) {
        StackedSplineSeriesDescriptionMetadata.b(a);
        a.aa("StackedSplineSeries", function () { return new StackedSplineSeriesDescription(); });
        a.z("StackedSplineSeries", StackedSplineSeriesDescriptionMetadata.a);
    };
    StackedSplineSeriesDescriptionMetadata.$t = markType(StackedSplineSeriesDescriptionMetadata, 'StackedSplineSeriesDescriptionMetadata');
    StackedSplineSeriesDescriptionMetadata.a = null;
    return StackedSplineSeriesDescriptionMetadata;
}(Base));
export { StackedSplineSeriesDescriptionMetadata };
